OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "仪表盘",
    "Dashboard app" : "仪表盘应用",
    "Customize" : "自定义",
    "Edit widgets" : "编辑小部件",
    "Get more widgets from the App Store" : "从应用商店获取更多小部件",
    "Change background image" : "更改背景图片",
    "Weather service" : "天气服务",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "为了您的隐私，天气数据由您的 Nextcloud 服务器为您获取，这样天气服务就无法获得您的个人信息。",
    "Weather data from Met.no" : "天气数据获取自 Met.no",
    "geocoding with Nominatim" : "使用 Nominatim 地理编码",
    "elevation data from OpenTopoData" : "海拔数据获取自 OpenTopoData",
    "Weather" : "天气",
    "Status" : "状态",
    "Good morning" : "早上好",
    "Good morning, {name}" : "早上好，{name}",
    "Good afternoon" : "下午好",
    "Good afternoon, {name}" : "下午好，{name}",
    "Good evening" : "晚上好",
    "Good evening, {name}" : "晚上好，{name}",
    "Hello" : "你好",
    "Hello, {name}" : "你好， {name}",
    "Pick from Files" : "从文件中挑选",
    "Plain background" : "纯色背景",
    "Insert from {productName}" : "从 {productName} 插入",
    "Show something" : "显示信息",
    "Default images" : "默认图片"
},
"nplurals=1; plural=0;");
